## What's Changed

1.1.0 (2025-04-07)
==================

- JBT Background Units by @bsunnquist in https://github.com/spacetelescope/jwst_rogue_path_tool/pull/27
- Add more examples for observers by @bsunnquist in https://github.com/spacetelescope/jwst_rogue_path_tool/pull/26

1.0.0 (2024-12-19)
==================

- First Release